0.13.0 (June 2018)
==================

Bokeh Version ``0.13.0`` is an incremental update that adds a few
new features and fixes several bugs. Some of the highlights include:

* Improved hover tool fields for common stacked bar plot cases
* New ``CumSum`` transform to generate values from cumulative sums
  of CDS columns on the client side.

And several other bug fixes and docs additions. For full details see the
:bokeh-tree:`CHANGELOG`.

Migration Guide
---------------

NOTE: the 0.13.x series is a final series of small releases leading to a
1.0 release. For more information see the `project roadmap`_.

Max Websocket Message Size
~~~~~~~~~~~~~~~~~~~~~~~~~~

A new command line option ``--websocket-max-message-size`` for the Bokeh
server can be used to configure the Tornado ``websocket_max_message_size``
option. The default value is now 20mb, an increase from the previous
10mb implicit default.

New Hover fields
~~~~~~~~~~~~~~~~

Two new hover tooltip fields are now available:

* ``$name`` will preint the value of the ``name`` property of a glyph that
  is being hovered over.

* ``@$name`` will look up values from a column like a normal ``@`` field,
  but will use ``$name`` as the name of the column.

Both of these are espeically useful in conjunction with stacked bar plots.

BokehJS Build
~~~~~~~~~~~~~

The ``gulp`` tool was previously used as the build system for BokehJS. This
has been replaced with a smaller and simpler build script. This greatly
reduced the number of dependencies required to build BokehJS and a completely
clean NPM package security audit was obtained as a side effect.

To build now, run the commandf ``node make build`` instead of ``gulp build``.
Task names remained unchanged. If you want preserve the old workflow, e.g. to
aid ``git bisect``, it is suggested to create an alias for ``node make``,
e.g. in bash this would be ``alias gulp='node make'``.

Line Join Default
~~~~~~~~~~~~~~~~~

The default ``line_join`` style has been changed from ``miter`` to ``bevel``,
to avoid exaggerating corners where connected lines meet at a sharp angle.
The HTML Canvas ``miterLimit`` property is meant to prevent such issues,
but it does not appear to be respected by current browsers.


.. _project roadmap: https://bokehplots.com/pages/roadmap.html
